@@ -1,16 +1,16 @@
 test_that("with_default will fail with non-maybe values", {
   for_all(
     a = anything(),
-    property = \(a) with_default(a, default = 0) |> expect_error()
+    property = function(a) with_default(a, default = 0) %>% expect_error()
   )
 })
 
 test_that("with_default unwraps a just value", {
   for_all(
     a = anything(),
-    property = \(a)
-      just(a) |>
-        with_default(default = 0) |>
+    property = function(a)
+      just(a) %>%
+        with_default(default = 0) %>%
         expect_identical(a)
   )
 })
@@ -18,9 +18,9 @@ test_that("with_default unwraps a just value", {
 test_that("with_default returns the default with a nothing value", {
   for_all(
     a = anything(),
-    property = \(a)
-      nothing() |>
-        with_default(default = a) |>
+    property = function(a)
+      nothing() %>%
+        with_default(default = a) %>%
         expect_identical(a)
   )
 })
